@@ -342,7 +342,7 @@ class IRISNumberRequestTransportStep(rules.Step, HttpTransportMixin):
 
 class IRISNumberRequestProcessStep(rules.Step):
     """
-    Takes response data from tracelink systems and writes to the sqlite db
+    Takes response data from IRIS systems and writes to the sqlite db
     database file if the region supports that.
     """
 
@@ -377,8 +377,7 @@ class IRISNumberRequestProcessStep(rules.Step):
         # add tags to serial_numbers array
         for tag in tags:
             if format.lower() == 'sgtin-198' or format.lower() == 'sgtin-96':
-                sn = tag.text.replace(
-                    'urn:epc:tag:{0}:'.format(format).lower(), "")
+                sn = tag.text.split('.')[3]
                 serial_numbers.append(sn)
             elif format.lower() == 'sscc-96':
                 urn = tag.text.replace('urn:epc:tag:sscc-96:',
